@@ -6,8 +6,10 @@ use Cwd          qw(abs_path getcwd);
 use Env          qw(HOME);
 use POSIX        qw(strftime);
 use Term::ANSIColor;
-use File::XDG;
 use base 'Reply::Plugin';
+use Exporter qw(import);
+our @EXPORT =
+  qw(section_result section_path section_os section_version section_time);
 
 BEGIN {
     if ( $^O eq 'MSWin32' ) {
@@ -16,6 +18,23 @@ BEGIN {
     }
 }
 
+my @sections = ( 'result', 'os', 'version', 'path', 'time' );    # section order
+my %section_colors = (    # section colors
+    'result'  => 'yellow on_red',
+    'os'      => 'black on_yellow',
+    'version' => 'blue on_black',
+    'path'    => 'white on_blue',
+    'time'    => 'black on_white',
+);
+my $sep            = '';         # section separator
+my $insert_text    = ' %s ';      # whitespaces which padded around section text
+my $insert_result  = '✘ %s';
+my $insert_version = ' %s';
+my $insert_os      = '%s';
+my $insert_time    = ' %s';
+my $time_format    = '%H:%M:%S';  # time format
+my $prompt_char    = '❯ ';        # prompt character
+
 sub new {
     my $class = shift;
     my $self  = $class->SUPER::new(@_);
@@ -90,48 +109,9 @@ sub section_time {
     return strftime( shift, localtime );
 }
 
-### Config
-### Section Order
-
-my @sections = ( 'result', 'os', 'version', 'path', 'time' );
-
-### Section Colors
-
-my %section_colors = (
-    'result'  => 'yellow on_red',
-    'os'      => 'black on_yellow',
-    'version' => 'blue on_black',
-    'path'    => 'white on_blue',
-    'time'    => 'black on_white',
-);
-
-### Section Separator
-
-my $sep = '';
-
-### Whitespaces Which Padded Around Section Text
-
-my $insert_text = ' %s ';
-
-### Section Text
-
-my $insert_result  = '✘ %s';
-my $insert_version = ' %s';
-my $insert_os      = '%s';
-my $insert_time    = ' %s';
-
-### Time Format
-
-my $time_format = '%H:%M:%S';
-
-### Prompt Character
-
-my $prompt_char = '❯ ';
-
-### Config
-
-my $xdg = File::XDG->new( name => 'reply', api => 1 );
 try {
+    require File::XDG;
+    my $xdg    = File::XDG->new( name => 'reply', api => 1 );
     my $config = $xdg->config_home->child('prompt.pl')->slurp_utf8;
     eval $config;
 }
@@ -141,8 +121,8 @@ catch ($err) {
 # these information will not change so source them once.
 my $os      = section_os;
 my $version = section_version;
-$insert_version = sprintf($insert_version, $version);
-$insert_os      = sprintf($insert_os, $os);
+$insert_version = sprintf( $insert_version, $version );
+$insert_os      = sprintf( $insert_os,      $os );
 
 sub prompt {
     my $self = shift;
@@ -167,14 +147,14 @@ sub prompt {
     foreach my $section (@new_sections) {
         my $text = '';
         if ( $section eq 'result' ) {
-            $text = sprintf($insert_result, $result);
+            $text = sprintf( $insert_result, $result );
         }
         elsif ( $section eq 'path' ) {
             $text = section_path;
         }
         elsif ( $section eq 'time' ) {
             my $time = section_time $time_format;
-            $text = sprintf($insert_time, $time);
+            $text = sprintf( $insert_time, $time );
         }
         elsif ( $section eq 'os' ) {
             $text = $insert_os;
@@ -190,7 +170,7 @@ sub prompt {
             my ($bg) = $color =~ /(?<=on_)(\S+)/g;
             $ps1 .= color("$last_bg on_$bg") . $sep;
         }
-        $ps1 .= color($color) . sprintf($insert_text, $text);
+        $ps1 .= color($color) . sprintf( $insert_text, $text );
         ($last_bg) = $color =~ /(?<=on_)(\S+)/g;
     }
     return
@@ -221,4 +201,42 @@ Reply::Plugin::Prompt - reply plugin for powerlevel10k style prompt
 
 =head1 DESCRIPTION
 
-See README.md for screenshots.
+L<Reply> plugin for L<powerlevel10k|https://github.com/romkatv/powerlevel10k>
+style prompt. It is an enhancement of L<Reply::Plugin::FancyPrompt>.
+
+Your perl deserves a beautiful REPL. See
+L<README.md|https://github.com/Freed-Wu/Reply-Plugin-Prompt> for screenshots.
+
+=head1 CONFIGURE
+
+=head2 ENABLE
+
+Enable this plugin in your F<~/.replyrc>:
+
+    [Prompt]
+
+=head2 CUSTOMIZE
+
+Install L<nerd-font|https://github.com/ryanoasis/nerd-fonts> firstly.
+
+Install L<File::XDG> > 1.00, then edit
+F<${XDG_CONFIG_PATH:-$HOME/.config}/reply/prompt.pl>:
+
+=encoding utf-8
+
+    @sections = ( 'result', 'os', 'version', 'path', 'time' );    # section order
+    %section_colors = (    # section colors
+        'result'  => 'yellow on_red',
+        'os'      => 'black on_yellow',
+        'version' => 'blue on_black',
+        'path'    => 'white on_blue',
+        'time'    => 'black on_white',
+    );
+    $sep            = '';         # section separator
+    $insert_text    = ' %s ';      # whitespaces which padded around section text
+    $insert_result  = '✘ %s';
+    $insert_version = ' %s';
+    $insert_os      = '%s';
+    $insert_time    = ' %s';
+    $time_format    = '%H:%M:%S';  # time format
+    $prompt_char    = '❯ ';        # prompt character
